@@ -8,7 +8,11 @@ standardize <- function(vec,j){#worst level is the actual observation, we're loo
 }
 
 pass.ev <-function(i, df, dag.grain){
-  ev <- querygrain(setEvidence(dag.grain,evidence=list(df[dim(df)[1],-i]), nodes=colnames(df)[i]))
+  evidence_row <- df[dim(df)[1], -i]
+  # Create a named list where names are the column names and values are character vectors
+  evidence_list <- as.list(evidence_row)
+  evidence_list <- lapply(evidence_list, as.character)
+  ev <- querygrain(setEvidence(dag.grain,evidence=evidence_list, nodes=colnames(df)[i]))
   ev2 <- ev[match(names(df),names(ev))]  #reordering to match
   evi <- ev2[[i]]
   return(evi)
