@@ -12,8 +12,9 @@
 #' @aliases cachexia_gbn
 #' @name cachexia
 #'
-#'@source	C. Görgen & M. Leonelli (2020), Model-preserving sensitivity analysis for families of Gaussian distributions.  Journal of Machine Learning Research, 21: 1-32.
-#'NULL
+#'@references	C. Görgen & M. Leonelli (2020), Model-preserving sensitivity analysis for families of Gaussian distributions.  Journal of Machine Learning Research, 21: 1-32.
+#'
+NULL
 
 #'
 #' @rdname cachexia
